@@ -6,17 +6,17 @@ function ibm_j2re_detect() {
     i386|i486-linux-gnu)
       case "$archive_name" in
         "IBMJava2-JRE-131.tgz") # SUPPORTED
-	    j2se_version=1.3.1
+	    j2se_version=1.3.1${revision}
 	    j2se_expected_min_size=20 #  bytes
 	    found=true
 	    ;;
         "IBMJava2-JRE-142.tgz") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=37 #  bytes
 	    found=true
 	    ;;
         "ibm-java2-jre-50-linux-i386.tgz") # SUPPORTED
-	    j2se_version=1.5.0
+	    j2se_version=1.5.0${revision}
 	    j2se_expected_min_size=40 # 41655352 bytes
 	    found=true
 	    ;;
@@ -25,12 +25,12 @@ function ibm_j2re_detect() {
     amd64|x86_64-linux-gnu)
       case "$archive_name" in
         "IBMJava2-JRE-AMD64-142.x86_64.tgz") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=37
 	    found=true
 	    ;;
         "ibm-java2-jre-50-linux-x86_64.tgz") # SUPPORTED
-	    j2se_version=1.5.0
+	    j2se_version=1.5.0${revision}
 	    j2se_expected_min_size=46 # 48018851 bytes
 	    found=true
 	    ;;
@@ -39,31 +39,36 @@ function ibm_j2re_detect() {
     powerpc|powerpc-linux)
       case "$archive_name" in
         "IBMJava2-JRE-131.ppc.tgz") # SUPPORTED
-	    j2se_version=1.3.1
+	    j2se_version=1.3.1${revision}
 	    j2se_expected_min_size=20 #  bytes
 	    found=true
 	    ;;
         "IBMJava2-JRE-142.ppc.tgz") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=40 #  bytes
 	    found=true
 	    ;;
         "ibm-java2-jre-50-linux-ppc.tgz") # SUPPORTED
-	    j2se_version=1.5.0
+	    j2se_version=1.5.0${revision}
 	    j2se_expected_min_size=42 # 43687702 bytes
 	    found=true
 	    ;;
+	"ibm-java2-jre-5.0-5.0-linux-ppc.tgz") # SUPPORTED
+            j2se_version=1.5.0${revision}
+            j2se_expected_min_size=50 # 50066027 bytes
+            found=true
+            ;;
       esac
       ;;
     powerpc64|powerpc64-linux)
       case "$archive_name" in
         "IBMJava2-JRE-142.ppc64.tgz") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=37
 	    found=true
 	    ;;
         "ibm-java2-jre-50-linux-ppc64.tgz") # SUPPORTED
-	    j2se_version=1.5.0
+	    j2se_version=1.5.0${revision}
 	    j2se_expected_min_size=46 # 47734431 bytes
 	    found=true
 	    ;;
@@ -72,32 +77,32 @@ function ibm_j2re_detect() {
     s390|s390-linux)
       case "$archive_name" in
         "IBMJava2-JRE-131.s390.tgz") # SUPPORTED
-	    j2se_version=1.3.1
+	    j2se_version=1.3.1${revision}
 	    j2se_expected_min_size=20
 	    found=true
 	    ;;
         "IBMJava2-JRE-141.s390.tgz") # SUPPORTED
-	    j2se_version=1.4.1
+	    j2se_version=1.4.1${revision}
 	    j2se_expected_min_size=31
 	    found=true
 	    ;;
         "IBMJava2-JRE-142.s390.tgz") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=34
 	    found=true
 	    ;;
         "IBMJava2-JRE-142.s390x.tgz") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=34
 	    found=true
 	    ;;
         "ibm-java2-jre-50-s390.tgz") # SUPPORTED
-	    j2se_version=1.5.0
+	    j2se_version=1.5.0${revision}
 	    j2se_expected_min_size=42 # 43686815 bytes
 	    found=true
 	    ;;
         "ibm-java2-jre-50-s390x.tgz") # SUPPORTED
-	    j2se_version=1.5.0
+	    j2se_version=1.5.0${revision}
 	    j2se_expected_min_size=42 # 43773066 bytes
 	    found=true
 	    ;;
