@@ -20,6 +20,11 @@ function ibm_j2sdk_detect() {
 	    j2se_expected_min_size=56 # 58162719 bytes
 	    found=true
 	    ;;
+        "ibm-java2-sdk-5.0-6.0-linux-i386.tgz") # SUPPORTED
+	    j2se_version=1.5.0${revision}
+	    j2se_expected_min_size=69 # 71512415 bytes
+	    found=true
+	    ;;
 	"ibm-java-sdk-60-linux-i386-20070329.tgz" ) # SUPPORTED
 	    j2se_version=1.6.0${revision}
 	    j2se_expected_min_size=61 # 63942070 bytes
@@ -44,6 +49,11 @@ function ibm_j2sdk_detect() {
 	    j2se_expected_min_size=57 # 59706399 bytes
 	    found=true
 	    ;;
+        "ibm-java2-sdk-5.0-6.0-linux-x86_64.tgz") # SUPPORTED
+	    j2se_version=1.5.0${revision}
+	    j2se_expected_min_size=69 # 71512415 bytes
+	    found=true
+	    ;;
 	"ibm-java-sdk-60-linux-x86_64-20070329.tgz" ) # SUPPORTED
 	    j2se_version=1.6.0${revision}
 	    j2se_expected_min_size=61 # 63942070 bytes
@@ -78,6 +88,11 @@ function ibm_j2sdk_detect() {
 	    j2se_expected_min_size=61 # 63942070 bytes
 	    found=true
 	    ;;
+        "ibm-java2-sdk-5.0-6.0-linux-ppc.tgz") # SUPPORTED
+	    j2se_version=1.5.0${revision}
+	    j2se_expected_min_size=69 # 71512415 bytes
+	    found=true
+	    ;;
 	"ibm-java-sdk-60-linux-ppc32-20070329.tgz" ) # SUPPORTED
 	    j2se_version=1.6.0${revision}
 	    j2se_expected_min_size=61 # 63942070 bytes
