@@ -17,7 +17,7 @@ $j2se_package ($j2se_version) unstable; urgency=low
 
   * This package was created with java-package ($version).
 
- -- $maintainer_name <$maintainer_email>  $( 822-date )
+ -- $maintainer_name <$maintainer_email>  $( date -R )
 
 EOF
 }
